summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBastien Guerry <bzg@altern.org>2008-03-01 13:13:45 +0000
committerBastien Guerry <bzg@altern.org>2008-03-01 13:13:45 +0000
commitbf09955fec57307616926959b31e19af42520db0 (patch)
treeeefc794aa436ea096af024cc624ef33ca25d7fdc
parentf247d16417f17140a5bd5d03db164cc74191d9c1 (diff)
downloadorg-mode-bf09955fec57307616926959b31e19af42520db0.tar.gz
Bugfix for `org-archive-subtree'.
The bug was this: when inserting an entry at the end of an archive buffer, the entry would get folded within the previous entry fold. This prevented the entry to get the proper DONE keyword when required. This change also kill the archive buffer after archiving.
-rw-r--r--ChangeLog25
-rw-r--r--org.el6
2 files changed, 13 insertions, 18 deletions
diff --git a/ChangeLog b/ChangeLog
index eff85fc..91d7324 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,28 +1,23 @@
2008-03-01 Bastien Guerry <bzg@altern.org>
- * org.texi (Capturing Column View): Documented new parameters for
- the column view dynamic block: :maxlevel and :skip-empty-rows.
-
-2008-03-01 Bastien Guerry <bzg@altern.org>
-
* org.el (org-dblock-write:columnview, org-columns-capture-view):
Added support for :maxlevel and :skip-empty-rows as argument for
the columnview dynamic block.
+ (org-archive-subtree): Fixed a bug that prevented entries to get
+ marked DONE even when `org-archive-mark-done' was non-nil. Also
+ kill archive buffer after archiving.
+ (org-export-as-html): Kill buffer after export when necessary.
-2008-02-29 Bastien Guerry <bzg@altern.org>
+ * org-export-latex.el (org-export-as-latex): Kill buffer after
+ export when necessary.
+
+ * org.texi (Capturing Column View): Documented the new parameters
+ for the column view dynamic block: :maxlevel and :skip-empty-rows.
* org-irc.el: Require 'cl and 'erc. Added dynamically scoped
variables.
(org-irc-visit-erc): Bug fix: rename `chan' to `chan-name'.
-2008-02-29 Bastien Guerry <bzg@altern.org>
-
- * org.el (org-export-as-html): Kill buffer after
- export when `to-buffer' is nil.
-
- * org-export-latex.el (org-export-as-latex): Kill buffer after
- export when `to-buffer' is nil.
-
2008-02-29 Carsten Dominik <dominik@science.uva.nl>
* org.el (org-agenda-text-search-extra-files): Renamed from
@@ -90,7 +85,6 @@
2008-02-27 Carsten Dominik <dominik@science.uva.nl>
-
* org-irc.el: Modified the installation instructions.
* org.el (org-store-link): Removed the (require 'org-irc), this is
@@ -107,7 +101,6 @@
will be treated like negative values.
(org-show-todo-tree): Fix a small typo in the docstring.
-
2008-02-26 Carsten Dominik <dominik@science.uva.nl>
* org.el (org-agenda-to-appt): Set `org-deadline-warning-days' to
diff --git a/org.el b/org.el
index 46f5dfc..4e27ecc 100644
--- a/org.el
+++ b/org.el
@@ -8052,6 +8052,7 @@ this heading."
org-odd-levels-only
tr-org-odd-levels-only)))
(goto-char (point-min))
+ (show-all)
(if heading
(progn
(if (re-search-forward
@@ -8094,8 +8095,9 @@ this heading."
(setq n (concat "ARCHIVE_" (upcase (symbol-name e))))
(org-entry-put (point) n v)))))
- ;; Save the buffer, if it is not the same buffer.
- (if (not (eq this-buffer buffer)) (save-buffer))))
+ ;; Save and kill the buffer, if it is not the same buffer.
+ (if (not (eq this-buffer buffer))
+ (progn (save-buffer) (kill-buffer buffer)))))
;; Here we are back in the original buffer. Everything seems to have
;; worked. So now cut the tree and finish up.
(let (this-command) (org-cut-subtree))